<?php
//
// +---------------------------------------------------------------------------+
// | External Pages Plugin 1.0 for Geeklog - The Ultimate Weblog               |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the search     |
// | PHP files.                                                                |
// |                                                                           |
// | This is a generic functions.inc for Geeklog 1.3.6.  Edit this file with   |
// | your favorite editor and replace every instance of search with the name   |
// | of your plugin.  You will then have a skeletal working functions.inc.     |
// | See documentation to fill in API implementations you man need.            |
// | You must also fill in the two arrays in the uninstall routine for it to   |
// | work properly.                                                            |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2002 by the following authors:                              |
// |                                                                           |
// | Author: Tom Willett         -    tomw@pigstye.net                         |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    tomw@pigstye.net                         |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

/**
* This is the generic functions.inc for the Universal Plugin Toolkit for Geeklog.
* You need to change all instances of {plugin} with the name of your plugin.
*/

/**
* Language file Include
*/
$langfile = $_CONF['path'] . 'plugins/external/language/' . $_CONF['language'] . '.php';

if (file_exists ($langfile)) 
{
    include_once ($langfile);
}
else 
{
    include_once ($_CONF['path'] . 'plugins/external/language/english.php');
}

/*
* Include external config file
*/
require_once ($_CONF['path'] . 'plugins/external/config.php');

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementations                                        |
// +---------------------------------------------------------------------------+

/**
* shows the statistics for the external files plugin on stats.php.  If $showsitestats
* is 1 then we are to only print the overall stats in the 'site statistics box'
* otherwise we show the detailed stats for the photo album
*
* @showsitestate        int         Flag to let us know which stats to get
*/
function plugin_showstats_external($showsitestats) 
{
    global $LANG_EX00, $_CONF, $_TABLES;

    $stat_templates = new Template($_CONF['path_layout'] . 'stats');
    $stat_templates->set_file(array('itemstats'=>'itemstatistics.thtml',
                            'statrow'=>'singlestat.thtml'));
    if ($showsitestats == 1) {
        $total_pages=DB_count($_TABLES['external']);
        $retval = "<table border = '0' width='100%' cellspacing='0' cellpadding='0'>";
        $retval .= "<tr><td>{$LANG_EX00['externpages']}</td>";
        $retval .= "<td align='right'>" . $total_pages . "&nbsp;&nbsp </td></tr></table>";
    } else {
        $result = DB_query("SELECT url, title, hits from {$_TABLES['external']} WHERE hits > 0 ORDER BY hits desc LIMIT 10");
        $nrows  = DB_numRows($result);
        $retval .= COM_startBlock($LANG_EX00['topten'] . $LANG_EX00['externpages']);
        if ($nrows > 0) {
            $stat_templates->set_var('item_label',$LANG_EX00['titlemsg']);
            $stat_templates->set_var('stat_name', $LANG_EX00['hitsmsg']);
            for ($i = 0; $i < $nrows; $i++) {
                $A = DB_fetchArray($result);
                if (preg_match("/^(http:\/\/)/i",$A['url']) == 1) {
                    $stat_templates->set_var('item_url', $A['url']);
                } else {
                    $stat_templates->set_var('item_url', $_CONF['site_url'] . '/' . $A['url']);
                }
                $stat_templates->set_var('item_text', stripslashes($A['title']));
                $stat_templates->set_var('item_stat', $A['hits']);
                $stat_templates->parse('stat_row','statrow',true); 
            }
            $stat_templates->parse('output','itemstats');
            $retval .= $stat_templates->finish($stat_templates->get_var('output'));
        } else {
            $retval .= $LANG_EX00['noextern'];
        }	
        $retval .= COM_endBlock();
    }
    return $retval;
}

/**
* Geeklog is asking us to provide any new items that show up in the type drop-down
* on search.php.  Let's let users search external pages!
*
*/
function plugin_searchtypes_external() 
{
    global $LANG_EX00;

    $tmp['external'] = $LANG_EX00['externpages'];
    return $tmp;
}


/**
* this searches for pages matching the user query and returns an array of 
* for the header and table rows back to search.php where it will be formated and
* printed 
*
* @query            string          Keywords user is looking for
* @datestart        date/time       Start date to get results for
* @dateend          date/time       End date to get results for
* @topic            string          The topic they were searching in
* @type             string          Type of items they are searching
* @author           string          Get all results by this author
*
*/
function plugin_dopluginsearch_external($query, $datestart, $dateend, $topic, $type, $author) 
{
	global $_TABLES, $_CONF, $LANG_EX00;

    if (empty($type)) {
        $type = 'all';
    }

    // Bail if we aren't supppose to do our search
    if ($type <> 'all' AND $type <> 'external') {
        $plugin_results = new Plugin();
        $plugin_results->plugin_name = 'external';
        $plugin_results->searchlabel = $LANG_EX00['externpages'] . $LANG_EX00['results'];
        return $plugin_results;
    }

    // Build search SQL - Modified to exclude static PHP pages from search.
    $sql = "SELECT * from " . $_TABLES['external'];
    $result = DB_query($sql);

    
    // OK, now create new plugin object and insert table header labels
    require_once($_CONF['path_system'] . 'classes/plugin.class.php');
    $plugin_results = new Plugin();
    $plugin_results->plugin_name = 'external';
    $plugin_results->searchlabel = $LANG_EX00['externpages'] . $LANG_EX00['results'];
    $plugin_results->addSearchHeading($LANG_EX00['titlemsg']);
    $plugin_results->addSearchHeading($LANG_EX00['urlmsg']);
    $plugin_results->addSearchHeading($LANG_EX00['hitsmsg']);
    $mycount = DB_numRows($result);

    // NOTE if any of your data items need to be links then add them here! 
    // make sure data elements are in an array and in the same order as your
    // headings above!
	for ($i = 1; $i <= $mycount; $i++) {
        $A = DB_fetchArray($result);

        if(SEC_hasAccess($A[owner_id],$A[group_id],$A[perm_owner],$A[perm_group],$A[perm_members],$A[perm_anon])){
            if (preg_match("/^(http:\/\/)/i",$A['url']) == 1) {
                $pth = $A['url'];
                $url = $A['url'];
            } else {
                $pth = $_CONF['path_html'] . $A['url'];
                $url = $_CONF['site_url'] . '/' . $A['url'];
            }
            $cnts = implode('',file($pth));
            if (stristr($cnts,$query) != '') {
                $rcnt++;
                $A['title'] = stripslashes($A['title']);
                $row = array($A['title'],
                      '<a href="' . $url . '">' . $A['url'] . "</a>",
                     $A['hits']);
                $plugin_results->addSearchResult($row);
            }
  	    }
	
	}
    $plugin_results->num_searchresults = $rcnt;
    $plugin_results->num_itemssearched = DB_count($_TABLES['external']);

    return $plugin_results;
}

/**
* This will put an option for the plugin in the command and control block on moderation.php
*
* Add the plugin name, icon and link to the command and control block in moderation.php
*
* @return   array   Array containing (plugin name, admin url, url of plugin icon)
*
*/
function plugin_cclabel_external() 
{
    global $_CONF, $LANG_EX00;

    return array($LANG_EX00['externpages'],$_CONF['site_admin_url'] . '/plugins/external/index.php',$_CONF['site_url'] . '/external/images/external.gif');
}

/**
* Returns the administrative option for this plugin
*
* Adds the plugin to the Admin menu
*
* Universal Plugin:  Modify/Uncomment use it
*
* @return   array   Array containing (plugin name, plugin admin url, # of items in plugin or '')
*
*/
function plugin_getadminoption_external() 
{
    global $_CONF, $_TABLES, $LANG_EX00;

    if (SEC_hasRights('external.admin')) {
        return array($LANG_EX00['externpages'], $_CONF['site_admin_url'] . '/plugins/external/index.php', DB_count($_TABLES['external']));
    }
}

/**
* Checks the security of an external page updates the hit counter, or adds record if not there.
*
* @param    string  Page to check
* @return   boolean status of whether or not user has access
*
*/
function SEC_externalAccess($page) 
{
    global $_TABLES, $_CONF;
    
    $recs = DB_query("SELECT * from {$_TABLES['external']} WHERE url='$page' or url='{$_CONF['site_url']}/{$page}'",1);
    if (DB_numRows($recs)>0) {
        $A=DB_fetchArray($recs);
        $retval=SEC_hasAccess($A[owner_id],$A[group_id],$A[perm_owner],$A[perm_group],$A[perm_members],$A[perm_anon]);
        DB_query("UPDATE {$_TABLES['external']} set hits=hits+1 where exid={$A['exid']}",1);
    } else {
        DB_query("INSERT INTO {$_TABLES['external']} SET url='$page', title='$page', hits=1");
        $retval = true;
    }
    return $retval;
}

/**
* Removes the datastructures for this plugin from the Geeklog database.
* This routine will get called from the Plugin install program if user select De-Install or if Delete is used in the Plugin Editor.
* The Plugin Installer will also call this routine upon and install error to remove anything it has created.
* The Plugin installer will pass the optional parameter which will then double check that plugin has first been disabled. 
* 
* Returns True if all Plugin related data is removed without error
*
* @param    string   $installCheck     Defult is blank but if set, check if plugin is disabled first
* 
* @return   boolean True if successful false otherwise
*
*/  
function plugin_uninstall_external($installCheck='')
{
    global $_TABLES, $LANG_EX00;

    // The searchs need to be changed to the name of your plugin
    //
    $pi_name='external';
    $FEATURES = array ( 'external.admin');
    $TABLES = array ('external');
    
    // Check and see if plugin is still enabled - if so display warning and exit
    if ($installCheck != '' && DB_getItem($_TABLES['plugins'],'pi_enabled', 'pi_name = "' .$pi_name. '"')) {
	    COM_errorLog("Plugin is installed and enabled. Disable first if you want to de-install it",1);
		$display .= COM_startBlock($LANG_EX00['warning']);
		$display .= $LANG_EX00['enabled'];
		$display .= COM_endBlock();
		echo $display;
		return false;
		exit;
	}
    	
	// Ok to proceed and delete plugin

    // Unregister the plugin with Geeklog
    COM_errorLog('Attempting to unregister the external plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'external'",1);

    // Drop external tables
    foreach($TABLES as $table) {
        $t = $_TABLES["$table"];
        COM_errorLog("Removing Table $t",1);
        DB_query("DROP TABLE $t",1);
    }

    // Remove Security for this plugin
    $grp_id = DB_getItem($_TABLES['vars'], 'value', "name = '{$pi_name}_gid'");
    
    COM_errorLog("Removing $pi_name Admin Group", 1);
    DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id",1);
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = '{$pi_name}_gid'");
    COM_errorLog("Removing root users from admin of $pi_name");
    DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id",1);
    
    // Remove all the associated features -- access rights
    foreach ($FEATURES as $feature) {
        COM_errorLog("Removing $feature feature and rights to it",1);
        $feat_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$feature'");
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $feat_id",1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $feat_id",1);
    }
        
    COM_errorLog('...success',1);
    return true;
}

?>